Python Cresco Client Library
===============
This library allows python applications to interface with Cresco via the WS_API plugin.

Installing
============

.. code-block:: bash

    pip install example-publish-pypi-medium

Usage
=====

.. code-block:: bash

    >>> from src.pycrescolib import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()pycrescolib.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()src.pycrescolib import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()pycrescolib.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()src.pycrescolib import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()pycrescolib.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()src.pycrescolib import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()pycrescolib.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()src.pycrescolib import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()pycrescolib.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()src.pycrescolib import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()pycrescolib.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src_test.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'
    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'